"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const definition_1 = require("../common/definition");
const commonFlags = require("../common/flags");
const openapi_client_axios_typegen_1 = require("openapi-client-axios-typegen");
class Typegen extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Typegen);
        const { dereference, validate, bundle, header, root } = flags;
        const definition = (0, definition_1.resolveDefinition)(args.definition);
        if (!definition) {
            this.error('Please load a definition file', { exit: 1 });
        }
        let document;
        try {
            document = await (0, definition_1.parseDefinition)({
                definition,
                dereference,
                bundle,
                validate,
                inject: flags.inject,
                strip: flags.strip,
                servers: flags.server,
                header,
                root,
            });
        }
        catch (err) {
            this.error(err, { exit: 1 });
        }
        const [imports, ...restTypes] = await (0, openapi_client_axios_typegen_1.generateTypesForDocument)(document, { transformOperationName: (name) => name });
        this.log([
            imports + '\n',
            ...restTypes,
        ].join('\n'));
    }
}
exports.default = Typegen;
Typegen.description = 'Generate types from openapi definition';
Typegen.examples = [
    `$ openapi typegen ./openapi.yml > openapi.d.ts`,
];
Typegen.flags = {
    ...commonFlags.help(),
    ...commonFlags.parseOpts(),
};
Typegen.args = [
    {
        name: 'definition',
        description: 'input definition file',
    },
];
